@@ -35,10 +35,10 @@ def load_any(
     x_scaling_factor=1.0,
     y_scaling_factor=1.0,
     z_scaling_factor=1.0,
+    anti_aliasing=True,
     load_parallel=False,
     sort_input_file=False,
     as_numpy=False,
-    verbose=False,
     n_free_cpus=2,
 ):
     """
@@ -56,6 +56,9 @@ def load_any(
         dimension (applied on loading before return)
     :param float z_scaling_factor: The scaling of the brain along the z
         dimension (applied on loading before return)
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
     :param bool load_parallel: Load planes in parallel using multiprocessing
         for faster data loading
     :param bool sort_input_file: If set to true and the input is a filepaths
@@ -75,6 +78,8 @@ def load_any(
             src_path,
             x_scaling_factor,
             y_scaling_factor,
+            z_scaling_factor,
+            anti_aliasing=anti_aliasing,
             file_extension=".tif",
             load_parallel=load_parallel,
             n_free_cpus=n_free_cpus,
@@ -85,13 +90,21 @@ def load_any(
             src_path,
             x_scaling_factor,
             y_scaling_factor,
+            z_scaling_factor,
+            anti_aliasing=anti_aliasing,
             load_parallel=load_parallel,
             sort=sort_input_file,
             n_free_cpus=n_free_cpus,
         )
-    elif src_path.endswith(".tif"):
+    elif src_path.endswith((".tif", ".tiff")):
         logging.debug("Data type is: tif stack")
-        img = load_img_stack(src_path)
+        img = load_img_stack(
+            src_path,
+            x_scaling_factor,
+            y_scaling_factor,
+            z_scaling_factor,
+            anti_aliasing=anti_aliasing,
+        )
     elif src_path.endswith(".nrrd"):
         logging.debug("Data type is: nrrd")
         img = load_nrrd(src_path)
@@ -102,8 +115,7 @@ def load_any(
         raise NotImplementedError(
             "Could not guess data type for path {}".format(src_path)
         )
-    if z_scaling_factor != 1:
-        img = scale_z(img, z_scaling_factor, verbose=verbose)
+
     return img
 
 
@@ -120,16 +132,41 @@ def load_nrrd(src_path):
     return stack
 
 
-def load_img_stack(stack_path):
+def load_img_stack(
+    stack_path,
+    x_scaling_factor,
+    y_scaling_factor,
+    z_scaling_factor,
+    anti_aliasing=True,
+):
     """
     Load a tiff stack as a numpy array
 
     :param str stack_path: The path of the image to be loaded
+    :param float x_scaling_factor: The scaling of the brain along the x
+        dimension (applied on loading before return)
+    :param float y_scaling_factor: The scaling of the brain along the y
+        dimension (applied on loading before return)
+    :param float z_scaling_factor: The scaling of the brain along the z
+        dimension (applied on loading before return)
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
     :return: The loaded brain array
     :rtype: np.ndarray
     """
     stack_path = str(stack_path)
     stack = tifffile.imread(stack_path)
+
+    if not (x_scaling_factor == y_scaling_factor == z_scaling_factor == 1):
+        stack = transform.rescale(
+            stack,
+            (x_scaling_factor, y_scaling_factor, z_scaling_factor),
+            mode="constant",
+            preserve_range=True,
+            anti_aliasing=anti_aliasing,
+        )
+
     return stack
 
 
@@ -160,6 +197,8 @@ def load_from_folder(
     src_folder,
     x_scaling_factor,
     y_scaling_factor,
+    z_scaling_factor,
+    anti_aliasing=True,
     file_extension="",
     load_parallel=False,
     n_free_cpus=2,
@@ -176,6 +215,11 @@ def load_from_folder(
         dimension (applied on loading before return)
     :param float y_scaling_factor: The scaling of the brain along the y
         dimension (applied on loading before return)
+    :param float z_scaling_factor: The scaling of the brain along the z
+        dimension
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
     :param str file_extension: will have to be present in the file names for them\
         to be considered part of the sample
     :param bool load_parallel: Use multiprocessing to speedup image loading
@@ -185,20 +229,22 @@ def load_from_folder(
     """
     paths = get_sorted_file_paths(src_folder, file_extension=file_extension)
 
-    if load_parallel:
-        return threaded_load_from_sequence(
-            paths, x_scaling_factor, y_scaling_factor, n_free_cpus=n_free_cpus
-        )
-    else:
-        return load_from_paths_sequence(
-            paths, x_scaling_factor, y_scaling_factor
-        )
+    return load_image_series(
+        paths,
+        x_scaling_factor,
+        y_scaling_factor,
+        z_scaling_factor,
+        load_parallel=load_parallel,
+        n_free_cpus=n_free_cpus,
+    )
 
 
 def load_img_sequence(
     img_sequence_file_path,
     x_scaling_factor,
     y_scaling_factor,
+    z_scaling_factor,
+    anti_aliasing=True,
     load_parallel=False,
     sort=False,
     n_free_cpus=2,
@@ -213,6 +259,11 @@ def load_img_sequence(
         dimension (applied on loading before return)
     :param float y_scaling_factor: The scaling of the brain along the y
         dimension (applied on loading before return)
+    :param float z_scaling_factor: The scaling of the brain along the z
+        dimension
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
     :param bool load_parallel: Use multiprocessing to speedup image loading
     :param bool sort: If set to true will perform a natural sort of the
         file paths in the list
@@ -227,18 +278,65 @@ def load_img_sequence(
     if sort:
         paths = natsorted(paths)
 
+    return load_image_series(
+        paths,
+        x_scaling_factor,
+        y_scaling_factor,
+        z_scaling_factor,
+        load_parallel=load_parallel,
+        n_free_cpus=n_free_cpus,
+    )
+
+
+def load_image_series(
+    paths,
+    x_scaling_factor,
+    y_scaling_factor,
+    z_scaling_factor,
+    anti_aliasing=True,
+    load_parallel=False,
+    n_free_cpus=2,
+):
+    """
+    Load a brain from a sequence of files specified in a text file containing
+    an ordered list of paths
+
+    :param lost paths: Ordered list of image paths
+    :param float x_scaling_factor: The scaling of the brain along the x
+        dimension (applied on loading before return)
+    :param float y_scaling_factor: The scaling of the brain along the y
+        dimension (applied on loading before return)
+    :param float z_scaling_factor: The scaling of the brain along the z
+        dimension
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
+    :param bool load_parallel: Use multiprocessing to speedup image loading
+    :param int n_free_cpus: Number of cpu cores to leave free.
+    :return: The loaded and scaled brain
+    :rtype: np.ndarray
+    """
+
     if load_parallel:
-        return threaded_load_from_sequence(
+        img = threaded_load_from_sequence(
             paths, x_scaling_factor, y_scaling_factor, n_free_cpus=n_free_cpus
         )
     else:
-        return load_from_paths_sequence(
+        img = load_from_paths_sequence(
             paths, x_scaling_factor, y_scaling_factor
         )
+    if z_scaling_factor != 1:
+        img = scale_z(img, z_scaling_factor)
+
+    return img
 
 
 def threaded_load_from_sequence(
-    paths_sequence, x_scaling_factor=1.0, y_scaling_factor=1.0, n_free_cpus=2
+    paths_sequence,
+    x_scaling_factor=1.0,
+    y_scaling_factor=1.0,
+    anti_aliasing=True,
+    n_free_cpus=2,
 ):
     """
     Use multiprocessing to load a brain from a sequence of image paths.
@@ -249,6 +347,9 @@ def threaded_load_from_sequence(
         dimension (applied on loading before return)
     :param float y_scaling_factor: The scaling of the brain along the y
         dimension (applied on loading before return)
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
     :param int n_free_cpus: Number of cpu cores to leave free.
     :return: The loaded and scaled brain
     :rtype: np.ndarray
@@ -283,7 +384,10 @@ def threaded_load_from_sequence(
 
 
 def load_from_paths_sequence(
-    paths_sequence, x_scaling_factor=1.0, y_scaling_factor=1.0
+    paths_sequence,
+    x_scaling_factor=1.0,
+    y_scaling_factor=1.0,
+    anti_aliasing=True,
 ):
     # TODO: Optimise -  load threaded and process by batch
     """
@@ -296,6 +400,9 @@ def load_from_paths_sequence(
         dimension (applied on loading before return)
     :param float y_scaling_factor: The scaling of the brain along the y
         dimension (applied on loading before return)
+    :param bool anti_aliasing: Whether to apply a Gaussian filter to smooth
+        the image prior to down-scaling. It is crucial to filter when
+        down-sampling the image to avoid aliasing artifacts.
     :return: The loaded and scaled brain
     :rtype: np.ndarray
     """
@@ -325,6 +432,7 @@ def load_from_paths_sequence(
                     (x_scaling_factor, y_scaling_factor),
                     mode="constant",
                     preserve_range=True,
+                    anti_aliasing=anti_aliasing,
                 )
         volume[:, :, i] = img
     return volume
